/**
 * Copyright (c) 2002-2011 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.onlinebackup;

import java.io.File;
import java.io.IOException;

/**
 * Check that the log file gets created in the given location.
 */
public class LogFileLocationTest extends SimpleRunningTest
{
    @Override
    public void clean()
    {
        super.clean();
        getLogFile().delete();
    }

    @Override
    protected void configureBackup( Backup backupComp ) throws IOException
    {
        backupComp.enableFileLogger( getLogFile().getPath() );
    }

    @Override
    public void backup() throws IOException
    {
        super.backup();
        File file = getLogFile();
        if ( !file.exists() )
        {
            org.junit.Assert.fail( "Backup log file not created." );
        }
        if ( !file.isFile() )
        {
            org.junit.Assert.fail( "Backup log file is not a file." );
        }
        if ( file.length() <= 0 )
        {
            org.junit.Assert.fail( "Backup log file is empty." );
        }
    }

    private File getLogFile()
    {
        return new File( "target/backuplogtest.log" );
    }
}
